package Astro::Constants::CGS;

require 5.004;
use strict;
use warnings;
use Astro::Constants;

require Exporter;
our @ISA = qw(Exporter);

use vars qw(
    $A_c $A_k $A_G $A_me $A_mp $A_amu $A_eV $A_h $A_hbar $A_e $A_mn $A_mH $A_pc $A_msun $A_rsun $A_AU $A_ly $A_Lsun $A_mearth $A_rearth $A_AA $A_Jy $A_rhoc $A_sigma $A_arad $A_sigmaT $A_re $A_a0 $A_Wien $A_alpha $A_NA $A_yr $A_tH $A_Tsun $A_TCMB $A_pi $A_exp $A_dsun $A_dearth $A_gsun $A_gearth $A_Vsun $A_MVsun $A_Z0 $A_eps0 $A_mu0 $A_rmoon $A_mmoon $A_amoon $A_emoon $A_inch $A_gogl
);

our %EXPORT_TAGS = ( 'short' => [ qw( 
    $A_c $A_k $A_G $A_me $A_mp $A_amu $A_eV $A_h $A_hbar $A_e $A_mn $A_mH $A_pc $A_msun $A_rsun $A_AU $A_ly $A_Lsun $A_mearth $A_rearth $A_AA $A_Jy $A_rhoc $A_sigma $A_arad $A_sigmaT $A_re $A_a0 $A_Wien $A_alpha $A_NA $A_yr $A_tH $A_Tsun $A_TCMB $A_pi $A_exp $A_dsun $A_dearth $A_gsun $A_gearth $A_Vsun $A_MVsun $A_Z0 $A_eps0 $A_mu0 $A_rmoon $A_mmoon $A_amoon $A_emoon $A_inch $A_gogl 
    list_constants describe_constants precision pretty ) ],
	 	      'long' => [ qw( 
    LIGHT_SPEED BOLTZMANN GRAVITATIONAL ELECTRON_MASS PROTON_MASS ATOMIC_MASS_UNIT ELECTRON_VOLT PLANCK HBAR ELECTRON_CHARGE NEUTRON_MASS HYDROGEN_MASS PARSEC SOLAR_MASS SOLAR_RADIUS ASTRONOMICAL_UNIT LIGHT_YEAR SOLAR_LUMINOSITY EARTH_MASS EARTH_RADIUS ANGSTROM JANSKY RHO_C STEFAN_BOLTZMANN A_RAD THOMSON_XSECTION ELECTRON_RADIUS BOHR_RADIUS WIEN ALPHA AVOGADRO YEAR HUBBLE_TIME SOLAR_TEMPERATURE CMB_TEMPERATURE PI EXP SOLAR_DENSITY EARTH_DENSITY SOLAR_GRAVITY EARTH_GRAVITY SOLAR_V_MAG SOLAR_V_ABS_MAG VACUUM_IMPEDANCE PERMITIV_FREE_SPACE PERMEABL_FREE_SPACE LUNAR_RADIUS LUNAR_MASS LUNAR_SM_AXIS LUNAR_ECCENTRICITY INCH GOOGOL 
    list_constants describe_constants precision pretty ) ] 
		   );

our @EXPORT_OK = qw( 
    $A_c $A_k $A_G $A_me $A_mp $A_amu $A_eV $A_h $A_hbar $A_e $A_mn $A_mH $A_pc $A_msun $A_rsun $A_AU $A_ly $A_Lsun $A_mearth $A_rearth $A_AA $A_Jy $A_rhoc $A_sigma $A_arad $A_sigmaT $A_re $A_a0 $A_Wien $A_alpha $A_NA $A_yr $A_tH $A_Tsun $A_TCMB $A_pi $A_exp $A_dsun $A_dearth $A_gsun $A_gearth $A_Vsun $A_MVsun $A_Z0 $A_eps0 $A_mu0 $A_rmoon $A_mmoon $A_amoon $A_emoon $A_inch $A_gogl 
    LIGHT_SPEED BOLTZMANN GRAVITATIONAL ELECTRON_MASS PROTON_MASS ATOMIC_MASS_UNIT ELECTRON_VOLT PLANCK HBAR ELECTRON_CHARGE NEUTRON_MASS HYDROGEN_MASS PARSEC SOLAR_MASS SOLAR_RADIUS ASTRONOMICAL_UNIT LIGHT_YEAR SOLAR_LUMINOSITY EARTH_MASS EARTH_RADIUS ANGSTROM JANSKY RHO_C STEFAN_BOLTZMANN A_RAD THOMSON_XSECTION ELECTRON_RADIUS BOHR_RADIUS WIEN ALPHA AVOGADRO YEAR HUBBLE_TIME SOLAR_TEMPERATURE CMB_TEMPERATURE PI EXP SOLAR_DENSITY EARTH_DENSITY SOLAR_GRAVITY EARTH_GRAVITY SOLAR_V_MAG SOLAR_V_ABS_MAG VACUUM_IMPEDANCE PERMITIV_FREE_SPACE PERMEABL_FREE_SPACE LUNAR_RADIUS LUNAR_MASS LUNAR_SM_AXIS LUNAR_ECCENTRICITY INCH GOOGOL 
    list_constants describe_constants precision pretty );

our @EXPORT = qw( list_constants() );
our $VERSION = Astro::Constants::Version();

$A_c = 2.997925e10;	# speed of light in a vacuum
$A_k = 1.380658e-16;	# Boltzmann's constant
$A_G = 6.67259e-8;	# universal gravitational constant
$A_me = 9.1093897e-28;	# mass of electron
$A_mp = 1.672631e-24;	# mass of proton
$A_amu = 1.6605402e-24;	# atomic mass unit
$A_eV = 1.6021772e-12;	# electron volt
$A_h = 6.6260755e-27;	# Planck's constant
$A_hbar = 1.0545727e-27;	# Planck's constant /2pi
$A_e = 4.8032e-10;	# electron charge (defined positive)
$A_mn = 1.6749286e-24;	# neutron mass
$A_mH = 1.6733e-24;	# mass of Hydrogen atom
$A_pc = 3.08567758e18;	# parsec
$A_msun = 1.99e33;	# solar mass
$A_rsun = 6.96e10;	# solar radius
$A_AU = 1.496e13;	# astronomical unit
$A_ly = 9.463e17;	# light year
$A_Lsun = 3.9e33;	# solar luminosity
$A_mearth = 5.976e27;	# mass of Earth
$A_rearth = 6.378e8;	# radius of Earth
$A_AA = 1e-8;	# Angstrom
$A_Jy = 1e-23;	# Jansky
$A_rhoc = 1.8791e-29;	# critical density /h^2
$A_sigma = 5.67040e-5;	# Stefan-Boltzmann constant
$A_arad = 7.5646e-15;	# radiation density constant
$A_sigmaT = 6.6524585e-25;	# Thomson cross-section
$A_re = 2.817941e-13;	# classical electron radius
$A_a0 = 5.29177208e-9;	# Bohr radius
$A_Wien = 2.897769e-1;	# Wien displacement law constant
$A_dsun = 1.408;	# mean solar density
$A_dearth = 5.515;	# mean Earth density
$A_gsun = 27400;	# solar surface gravity
$A_gearth = 978;	# Earth surface gravity
$A_eps0 = 1;	# permittivity of free space
$A_mu0 = 1;	# permeability of free space
$A_rmoon = 1738e5;	# lunar radius
$A_mmoon = 7.348e25;	# lunar mass
$A_amoon = 3.844e10;	# lunar orbital semi-major axis
$A_inch = 2.54;	# some outdated unit of distance

# Dimensionless constants start here
$A_alpha = (1.0/137.03599);	# fine structure constant
$A_NA = 6.0221367e23;	# Avogadro's number
$A_yr = 3.156e7;	# year
$A_tH = 3.0853056e17;	# Hubble time *h
$A_Tsun = 5780;	# surface temperature of sun
$A_TCMB = 2.726;	# cosmic microwave background temperature
$A_pi = 3.14159265358979324;	# trig constant pi
$A_exp = 2.71828182846;	# base of natural logarithm
$A_Vsun = -26.74;	# solar V magnitude
$A_MVsun = 4.83;	# solar absolute V magnitude
$A_Z0 = 376.730313461;	# characteristic impedance of vacuum
$A_emoon = 0.0549;	# lunar orbital eccentricity
$A_gogl = 1e100;	# a very, very large number

# These are the long names.
use constant LIGHT_SPEED 	=> 2.997925e10;	# speed of light in a vacuum
use constant BOLTZMANN 	=> 1.380658e-16;	# Boltzmann's constant
use constant GRAVITATIONAL 	=> 6.67259e-8;	# universal gravitational constant
use constant ELECTRON_MASS 	=> 9.1093897e-28;	# mass of electron
use constant PROTON_MASS 	=> 1.672631e-24;	# mass of proton
use constant ATOMIC_MASS_UNIT 	=> 1.6605402e-24;	# atomic mass unit
use constant ELECTRON_VOLT 	=> 1.6021772e-12;	# electron volt
use constant PLANCK 	=> 6.6260755e-27;	# Planck's constant
use constant HBAR 	=> 1.0545727e-27;	# Planck's constant /2pi
use constant ELECTRON_CHARGE 	=> 4.8032e-10;	# electron charge (defined positive)
use constant NEUTRON_MASS 	=> 1.6749286e-24;	# neutron mass
use constant HYDROGEN_MASS 	=> 1.6733e-24;	# mass of Hydrogen atom
use constant PARSEC 	=> 3.08567758e18;	# parsec
use constant SOLAR_MASS 	=> 1.99e33;	# solar mass
use constant SOLAR_RADIUS 	=> 6.96e10;	# solar radius
use constant ASTRONOMICAL_UNIT 	=> 1.496e13;	# astronomical unit
use constant LIGHT_YEAR 	=> 9.463e17;	# light year
use constant SOLAR_LUMINOSITY 	=> 3.9e33;	# solar luminosity
use constant EARTH_MASS 	=> 5.976e27;	# mass of Earth
use constant EARTH_RADIUS 	=> 6.378e8;	# radius of Earth
use constant ANGSTROM 	=> 1e-8;	# Angstrom
use constant JANSKY 	=> 1e-23;	# Jansky
use constant RHO_C 	=> 1.8791e-29;	# critical density /h^2
use constant STEFAN_BOLTZMANN 	=> 5.67040e-5;	# Stefan-Boltzmann constant
use constant A_RAD 	=> 7.5646e-15;	# radiation density constant
use constant THOMSON_XSECTION 	=> 6.6524585e-25;	# Thomson cross-section
use constant ELECTRON_RADIUS 	=> 2.817941e-13;	# classical electron radius
use constant BOHR_RADIUS 	=> 5.29177208e-9;	# Bohr radius
use constant WIEN 	=> 2.897769e-1;	# Wien displacement law constant
use constant SOLAR_DENSITY 	=> 1.408;	# mean solar density
use constant EARTH_DENSITY 	=> 5.515;	# mean Earth density
use constant SOLAR_GRAVITY 	=> 27400;	# solar surface gravity
use constant EARTH_GRAVITY 	=> 978;	# Earth surface gravity
use constant PERMITIV_FREE_SPACE 	=> 1;	# permittivity of free space
use constant PERMEABL_FREE_SPACE 	=> 1;	# permeability of free space
use constant LUNAR_RADIUS 	=> 1738e5;	# lunar radius
use constant LUNAR_MASS 	=> 7.348e25;	# lunar mass
use constant LUNAR_SM_AXIS 	=> 3.844e10;	# lunar orbital semi-major axis
use constant INCH 	=> 2.54;	# some outdated unit of distance

# Dimensionless constants with long names start here
use constant ALPHA 	=> (1.0/137.03599);	# fine structure constant
use constant AVOGADRO 	=> 6.0221367e23;	# Avogadro's number
use constant YEAR 	=> 3.156e7;	# year
use constant HUBBLE_TIME 	=> 3.0853056e17;	# Hubble time *h
use constant SOLAR_TEMPERATURE 	=> 5780;	# surface temperature of sun
use constant CMB_TEMPERATURE 	=> 2.726;	# cosmic microwave background temperature
use constant PI 	=> 3.14159265358979324;	# trig constant pi
use constant EXP 	=> 2.71828182846;	# base of natural logarithm
use constant SOLAR_V_MAG 	=> -26.74;	# solar V magnitude
use constant SOLAR_V_ABS_MAG 	=> 4.83;	# solar absolute V magnitude
use constant VACUUM_IMPEDANCE 	=> 376.730313461;	# characteristic impedance of vacuum
use constant LUNAR_ECCENTRICITY 	=> 0.0549;	# lunar orbital eccentricity
use constant GOOGOL 	=> 1e100;	# a very, very large number


# These are the functions that access a few properties of the constants

my @shortnames = qw(
    $A_c $A_k $A_G $A_me $A_mp $A_amu $A_eV $A_h $A_hbar $A_e $A_mn $A_mH $A_pc $A_msun $A_rsun $A_AU $A_ly $A_Lsun $A_mearth $A_rearth $A_AA $A_Jy $A_rhoc $A_sigma $A_arad $A_sigmaT $A_re $A_a0 $A_Wien $A_alpha $A_NA $A_yr $A_tH $A_Tsun $A_TCMB $A_pi $A_exp $A_dsun $A_dearth $A_gsun $A_gearth $A_Vsun $A_MVsun $A_Z0 $A_eps0 $A_mu0 $A_rmoon $A_mmoon $A_amoon $A_emoon $A_inch $A_gogl
);

my @longnames = qw(
    LIGHT_SPEED BOLTZMANN GRAVITATIONAL ELECTRON_MASS PROTON_MASS ATOMIC_MASS_UNIT ELECTRON_VOLT PLANCK HBAR ELECTRON_CHARGE NEUTRON_MASS HYDROGEN_MASS PARSEC SOLAR_MASS SOLAR_RADIUS ASTRONOMICAL_UNIT LIGHT_YEAR SOLAR_LUMINOSITY EARTH_MASS EARTH_RADIUS ANGSTROM JANSKY RHO_C STEFAN_BOLTZMANN A_RAD THOMSON_XSECTION ELECTRON_RADIUS BOHR_RADIUS WIEN ALPHA AVOGADRO YEAR HUBBLE_TIME SOLAR_TEMPERATURE CMB_TEMPERATURE PI EXP SOLAR_DENSITY EARTH_DENSITY SOLAR_GRAVITY EARTH_GRAVITY SOLAR_V_MAG SOLAR_V_ABS_MAG VACUUM_IMPEDANCE PERMITIV_FREE_SPACE PERMEABL_FREE_SPACE LUNAR_RADIUS LUNAR_MASS LUNAR_SM_AXIS LUNAR_ECCENTRICITY INCH GOOGOL
);

my %description = (
	'PERMEABL_FREE_SPACE' => q(permeability of free space),
 	'A_tH' => q(Hubble time *h),
 	'A_gsun' => q(solar surface gravity),
 	'EARTH_DENSITY' => q(mean Earth density),
 	'A_msun' => q(solar mass),
 	'A_Lsun' => q(solar luminosity),
 	'A_emoon' => q(lunar orbital eccentricity),
 	'A_TCMB' => q(cosmic microwave background temperature),
 	'A_e' => q(electron charge (defined positive)),
 	'A_dearth' => q(mean Earth density),
 	'A_arad' => q(radiation density constant),
 	'A_exp' => q(base of natural logarithm),
 	'LUNAR_SM_AXIS' => q(lunar orbital semi-major axis),
 	'EXP' => q(base of natural logarithm),
 	'STEFAN_BOLTZMANN' => q(Stefan-Boltzmann constant),
 	'EARTH_RADIUS' => q(radius of Earth),
 	'LUNAR_ECCENTRICITY' => q(lunar orbital eccentricity),
 	'THOMSON_XSECTION' => q(Thomson cross-section),
 	'A_eps0' => q(permittivity of free space),
 	'A_mp' => q(mass of proton),
 	'LUNAR_RADIUS' => q(lunar radius),
 	'SOLAR_TEMPERATURE' => q(surface temperature of sun),
 	'AVOGADRO' => q(Avogadro's number),
 	'A_Vsun' => q(solar V magnitude),
 	'SOLAR_V_MAG' => q(solar V magnitude),
 	'A_re' => q(classical electron radius),
 	'ELECTRON_VOLT' => q(electron volt),
 	'A_a0' => q(Bohr radius),
 	'A_rearth' => q(radius of Earth),
 	'A_mmoon' => q(lunar mass),
 	'A_rsun' => q(solar radius),
 	'A_rhoc' => q(critical density /h^2),
 	'PARSEC' => q(parsec),
 	'JANSKY' => q(Jansky),
 	'A_RAD' => q(radiation density constant),
 	'A_hbar' => q(Planck's constant /2pi),
 	'A_gearth' => q(Earth surface gravity),
 	'A_MVsun' => q(solar absolute V magnitude),
 	'A_AA' => q(Angstrom),
 	'LIGHT_SPEED' => q(speed of light in a vacuum),
 	'SOLAR_RADIUS' => q(solar radius),
 	'SOLAR_V_ABS_MAG' => q(solar absolute V magnitude),
 	'PROTON_MASS' => q(mass of proton),
 	'ASTRONOMICAL_UNIT' => q(astronomical unit),
 	'NEUTRON_MASS' => q(neutron mass),
 	'ATOMIC_MASS_UNIT' => q(atomic mass unit),
 	'BOHR_RADIUS' => q(Bohr radius),
 	'INCH' => q(some outdated unit of distance),
 	'A_rmoon' => q(lunar radius),
 	'A_NA' => q(Avogadro's number),
 	'A_mH' => q(mass of Hydrogen atom),
 	'A_h' => q(Planck's constant),
 	'SOLAR_GRAVITY' => q(solar surface gravity),
 	'WIEN' => q(Wien displacement law constant),
 	'HBAR' => q(Planck's constant /2pi),
 	'A_amu' => q(atomic mass unit),
 	'RHO_C' => q(critical density /h^2),
 	'A_gogl' => q(a very, very large number),
 	'LUNAR_MASS' => q(lunar mass),
 	'A_k' => q(Boltzmann's constant),
 	'A_dsun' => q(mean solar density),
 	'A_Jy' => q(Jansky),
 	'A_yr' => q(year),
 	'EARTH_GRAVITY' => q(Earth surface gravity),
 	'ELECTRON_CHARGE' => q(electron charge (defined positive)),
 	'SOLAR_DENSITY' => q(mean solar density),
 	'PLANCK' => q(Planck's constant),
 	'SOLAR_MASS' => q(solar mass),
 	'A_me' => q(mass of electron),
 	'A_mu0' => q(permeability of free space),
 	'ELECTRON_MASS' => q(mass of electron),
 	'SOLAR_LUMINOSITY' => q(solar luminosity),
 	'A_mearth' => q(mass of Earth),
 	'HUBBLE_TIME' => q(Hubble time *h),
 	'ALPHA' => q(fine structure constant),
 	'PERMITIV_FREE_SPACE' => q(permittivity of free space),
 	'A_pi' => q(trig constant pi),
 	'A_eV' => q(electron volt),
 	'ANGSTROM' => q(Angstrom),
 	'A_c' => q(speed of light in a vacuum),
 	'YEAR' => q(year),
 	'A_Z0' => q(characteristic impedance of vacuum),
 	'BOLTZMANN' => q(Boltzmann's constant),
 	'A_alpha' => q(fine structure constant),
 	'HYDROGEN_MASS' => q(mass of Hydrogen atom),
 	'GOOGOL' => q(a very, very large number),
 	'A_AU' => q(astronomical unit),
 	'A_sigmaT' => q(Thomson cross-section),
 	'A_amoon' => q(lunar orbital semi-major axis),
 	'CMB_TEMPERATURE' => q(cosmic microwave background temperature),
 	'GRAVITATIONAL' => q(universal gravitational constant),
 	'A_sigma' => q(Stefan-Boltzmann constant),
 	'A_ly' => q(light year),
 	'LIGHT_YEAR' => q(light year),
 	'A_mn' => q(neutron mass),
 	'A_Tsun' => q(surface temperature of sun),
 	'A_inch' => q(some outdated unit of distance),
 	'VACUUM_IMPEDANCE' => q(characteristic impedance of vacuum),
 	'EARTH_MASS' => q(mass of Earth),
 	'PI' => q(trig constant pi),
 	'A_pc' => q(parsec),
 	'A_G' => q(universal gravitational constant),
 	'A_Wien' => q(Wien displacement law constant),
 	'ELECTRON_RADIUS' => q(classical electron radius),

);

my %rel_precision = (
	'PERMEABL_FREE_SPACE' => '0.1',
 	'A_tH' => '0.0000001',
 	'A_gsun' => '0.0001',
 	'EARTH_DENSITY' => '0.001',
 	'A_msun' => '0.01',
 	'A_Lsun' => '0.1',
 	'A_emoon' => '0.0001',
 	'A_TCMB' => '0.001',
 	'A_e' => '0.0001',
 	'A_dearth' => '0.001',
 	'A_arad' => '0.0001',
 	'A_exp' => '0.00000000001',
 	'LUNAR_SM_AXIS' => '0.001',
 	'EXP' => '0.00000000001',
 	'STEFAN_BOLTZMANN' => '0.00001',
 	'EARTH_RADIUS' => '0.001',
 	'LUNAR_ECCENTRICITY' => '0.0001',
 	'THOMSON_XSECTION' => '0.0000001',
 	'A_eps0' => '0.1',
 	'A_mp' => '0.000001',
 	'LUNAR_RADIUS' => '0.0001',
 	'SOLAR_TEMPERATURE' => '0.001',
 	'AVOGADRO' => '0.0000001',
 	'A_Vsun' => '0.001',
 	'SOLAR_V_MAG' => '0.001',
 	'A_re' => '0.000001',
 	'ELECTRON_VOLT' => '0.0000001',
 	'A_a0' => '0.00000001',
 	'A_rearth' => '0.001',
 	'A_mmoon' => '0.001',
 	'A_rsun' => '0.01',
 	'A_rhoc' => '0.0001',
 	'PARSEC' => '0.00000001',
 	'JANSKY' => '0.1',
 	'A_RAD' => '0.0001',
 	'A_hbar' => '0.0000001',
 	'A_gearth' => '0.01',
 	'A_MVsun' => '0.01',
 	'A_AA' => '0.1',
 	'LIGHT_SPEED' => '0.000001',
 	'SOLAR_RADIUS' => '0.01',
 	'SOLAR_V_ABS_MAG' => '0.01',
 	'PROTON_MASS' => '0.000001',
 	'ASTRONOMICAL_UNIT' => '0.001',
 	'NEUTRON_MASS' => '0.0000001',
 	'ATOMIC_MASS_UNIT' => '0.0000001',
 	'BOHR_RADIUS' => '0.00000001',
 	'INCH' => '3e-3',
 	'A_rmoon' => '0.0001',
 	'A_NA' => '0.0000001',
 	'A_mH' => '0.0001',
 	'A_h' => '0.0000001',
 	'SOLAR_GRAVITY' => '0.0001',
 	'WIEN' => '0.000001',
 	'HBAR' => '0.0000001',
 	'A_amu' => '0.0000001',
 	'RHO_C' => '0.0001',
 	'A_gogl' => '0',
 	'LUNAR_MASS' => '0.001',
 	'A_k' => '0.000001',
 	'A_dsun' => '0.001',
 	'A_Jy' => '0.1',
 	'A_yr' => '0.001',
 	'EARTH_GRAVITY' => '0.01',
 	'ELECTRON_CHARGE' => '0.0001',
 	'SOLAR_DENSITY' => '0.001',
 	'PLANCK' => '0.0000001',
 	'SOLAR_MASS' => '0.01',
 	'A_me' => '0.0000001',
 	'A_mu0' => '0.1',
 	'ELECTRON_MASS' => '0.0000001',
 	'SOLAR_LUMINOSITY' => '0.1',
 	'A_mearth' => '0.001',
 	'HUBBLE_TIME' => '0.0000001',
 	'ALPHA' => '?',
 	'PERMITIV_FREE_SPACE' => '0.1',
 	'A_pi' => '0.00000000000000001',
 	'A_eV' => '0.0000001',
 	'ANGSTROM' => '0.1',
 	'A_c' => '0.000001',
 	'YEAR' => '0.001',
 	'A_Z0' => '0.00000000001',
 	'BOLTZMANN' => '0.000001',
 	'A_alpha' => '?',
 	'HYDROGEN_MASS' => '0.0001',
 	'GOOGOL' => '0',
 	'A_AU' => '0.001',
 	'A_sigmaT' => '0.0000001',
 	'A_amoon' => '0.001',
 	'CMB_TEMPERATURE' => '0.001',
 	'GRAVITATIONAL' => '0.00001',
 	'A_sigma' => '0.00001',
 	'A_ly' => '0.001',
 	'LIGHT_YEAR' => '0.001',
 	'A_mn' => '0.0000001',
 	'A_Tsun' => '0.001',
 	'A_inch' => '3e-3',
 	'VACUUM_IMPEDANCE' => '0.00000000001',
 	'EARTH_MASS' => '0.001',
 	'PI' => '0.00000000000000001',
 	'A_pc' => '0.00000001',
 	'A_G' => '0.00001',
 	'A_Wien' => '0.000001',
 	'ELECTRON_RADIUS' => '0.000001',

);

# should I return _two_ refs or one long list?
sub list_constants {
    return \@shortnames, \@longnames;
}

# These two routines require that the name of the constant be passed through
# enclosed by single quotes
# If called without an argument, the return a ref to the underlying hash

sub describe_constants {
    my $name = shift;
    return \%description unless defined $name;

    print "You probably need to enclose the constant $name in single quotes\n"
	if $name =~ /^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/;

    exists $description{$name} ? 
	return $description{$name} : return undef;
}

sub precision {
    my $name = shift;
    return \%rel_precision unless defined $name;

    print "You probably need to enclose the constant $name in single quotes\n"
	if $name =~ /^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/;

    exists $rel_precision{$name} ? 
	return $rel_precision{$name} : return undef;
}

sub pretty {
# would be nice if this could take a list
# OR even better, print out values only to their precision
# (What is the _right_ thing to do?)
    my $value = shift;	
    my $pretty = sprintf "%1.5e", $value;
    return $pretty;
}

1;
